## Keyword Dictionary

This is a [yaml](https://yaml.org/) file hosting a dictionary of the SOXS FITS Header keywords.

Having these keywords in a plain-text yaml file allows us to change the naming of a SOXS FITS Keyword in one location without having to edit the code.

